=== added file '.bzrignore'
--- .bzrignore	1970-01-01 00:00:00 +0000
+++ .bzrignore	2014-02-20 17:02:49 +0000
@@ -0,0 +1,1 @@
+./manual-provider-home

=== modified file 'common-startup.sh'
--- common-startup.sh	2014-02-20 19:23:39 +0000
+++ common-startup.sh	2014-02-21 19:46:13 +0000
@@ -1,6 +1,10 @@
 set -eu
-export JUJU_HOME=$HOME/juju-ci
-
+if [ "$ENV" = "manual" ]; then
+  export JUJU_HOME=$WORKSPACE/manual-provider-home
+  source $HOME/juju-ci/ec2rc
+else
+  export JUJU_HOME=$HOME/juju-ci
+fi
 
 dump_logs(){
   log_path=${artifacts_path}/all-machines-${ENV}.log
@@ -31,6 +35,8 @@
 source buildvars.bash
 echo "Testing $BRANCH $REVNO on $ENV"
 dpkg-deb -x $PACKAGE extracted-bin
-export NEW_PATH=$(dirname $(find extracted-bin -name juju)):$PATH
-# Try to ensure a clean environment
-$SCRIPTS/destroy-environment $ENV
+JUJU_BIN=$(readlink -f $(dirname $(find extracted-bin -name juju)))
+export NEW_PATH=$JUJU_BIN:$PATH
+if [ "$ENV" != "manual" ]; then
+  $SCRIPTS/destroy-environment $ENV
+fi

=== modified file 'deploy_stack.py'
--- deploy_stack.py	2014-01-29 20:45:10 +0000
+++ deploy_stack.py	2014-02-20 17:02:49 +0000
@@ -13,7 +13,7 @@
 )
 
 
-def deploy_stack(environments, charm_prefix):
+def deploy_stack(environments, charm_prefix, already_bootstrapped):
     """"Deploy a Wordpress stack in the specified environment.
 
     :param environment: The name of the desired environment.
@@ -23,7 +23,8 @@
         sys.path = [p for p in sys.path if 'OpenSSH' not in p]
     envs = [Environment.from_config(e) for e in environments]
     for env in envs:
-        env.bootstrap()
+        if not already_bootstrapped:
+            env.bootstrap()
     for env in envs:
         agent_version = env.get_matching_agent_version()
         status = env.get_status()
@@ -54,10 +55,13 @@
     parser = ArgumentParser('Deploy a WordPress stack')
     parser.add_argument('--charm-prefix', help='A prefix for charm urls.',
                         default='')
+    parser.add_argument('--already-bootstrapped',
+                        help='The environment is already bootstrapped.',
+                        action='store_true')
     parser.add_argument('env', nargs='*')
     args = parser.parse_args()
     try:
-        deploy_stack(args.env, args.charm_prefix)
+        deploy_stack(args.env, args.charm_prefix, args.already_bootstrapped)
     except Exception as e:
         print(e)
         sys.exit(1)

=== added file 'ec2-get-name'
--- ec2-get-name	1970-01-01 00:00:00 +0000
+++ ec2-get-name	2014-02-21 15:05:06 +0000
@@ -0,0 +1,11 @@
+#!/bin/bash
+set -eu
+instance_name=''
+echo -n Waiting for instance name >&2
+while [ -z "$instance_name" ]; do
+  sleep 1
+  instance_name=$(euca-describe-instances $1|sed '/^INSTANCE/!d'|cut -f 4)
+  echo -n . >&2
+done
+echo >&2
+echo $instance_name

=== added file 'ec2-run-instance-get-id'
--- ec2-run-instance-get-id	1970-01-01 00:00:00 +0000
+++ ec2-run-instance-get-id	2014-02-20 17:02:49 +0000
@@ -0,0 +1,7 @@
+#!/bin/bash
+set -eu
+RUN_OUTPUT=$(euca-run-instances -k id_rsa -t $INSTANCE_TYPE $AMI_IMAGE)
+if [ $? -ne 0 ]; then
+  exit 1
+fi
+echo $RUN_OUTPUT|sed -r 's/.*INSTANCE (i-[^ ]*) .*/\1/'

=== added file 'manual-deploy'
--- manual-deploy	1970-01-01 00:00:00 +0000
+++ manual-deploy	2014-02-21 17:50:25 +0000
@@ -0,0 +1,43 @@
+#!/bin/bash
+set -eux
+: ${SCRIPTS:=$(readlink -f $(dirname $0))}
+: ${JUJU_HOME:=$SCRIPTS/manual-provider-home}
+export JUJU_HOME
+echo $0
+export INSTANCE_TYPE=m1.large
+export AMI_IMAGE=ami-bd6d40d4
+machine_0_id=$($SCRIPTS/ec2-run-instance-get-id)
+machine_1_id=$($SCRIPTS/ec2-run-instance-get-id)
+machine_2_id=$($SCRIPTS/ec2-run-instance-get-id)
+machine_0_name=$($SCRIPTS/ec2-get-name $machine_0_id)
+machine_1_name=$($SCRIPTS/ec2-get-name $machine_1_id)
+machine_2_name=$($SCRIPTS/ec2-get-name $machine_2_id)
+
+$SCRIPTS/wait-for-port $machine_0_name 22
+rm -f $JUJU_HOME/environments/manual.jenv
+
+# Write new environments.yaml
+cat  > $JUJU_HOME/environments.yaml <<EOT
+environments:
+  manual:
+    type: manual
+    bootstrap-host: $machine_0_name
+    bootstrap-user: ubuntu
+    tools-metadata-url: http://juju-dist.s3.amazonaws.com/testing/tools
+EOT
+juju bootstrap --show-log -e manual
+$SCRIPTS/wait-for-port $machine_0_name 8040
+
+for machine in $machine_1_name $machine_2_name; do
+  $SCRIPTS/wait-for-port $machine 22
+  juju add-machine ssh:$machine
+done
+
+if $SCRIPTS/deploy_stack.py --already-bootstrapped manual; then
+  exit_code=0
+else
+  exit_code=1
+fi
+rm $JUJU_HOME/environments/manual.jenv
+euca-terminate-instances $machine_0_id $machine_1_id $machine_2_id
+exit $exit_code

=== added file 'manual-deploy-job'
--- manual-deploy-job	1970-01-01 00:00:00 +0000
+++ manual-deploy-job	2014-02-21 16:47:47 +0000
@@ -0,0 +1,10 @@
+#!/bin/bash
+export ENV=manual
+source $SCRIPTS/common-startup.sh
+if [ ! -d $JUJU_HOME ]; then
+  mkdir $JUJU_HOME
+fi
+# Do the deployment for upgrade testing.
+EXIT_STATUS=0
+JUJU_REPOSITORY=$HOME/repository PATH=$NEW_PATH $SCRIPTS/manual-deploy || EXIT_STATUS=$?
+exit $EXIT_STATUS

=== modified file 'run-unit-tests'
--- run-unit-tests	2014-02-14 21:49:26 +0000
+++ run-unit-tests	2014-02-21 19:23:09 +0000
@@ -1,36 +1,19 @@
 #!/bin/bash
 set -eux
 : ${LOCAL_JENKINS_URL=$JENKINS_URL}
-INSTANCE_TYPE=$1
-AMI_IMAGE=$2
+export INSTANCE_TYPE=$1
+export AMI_IMAGE=$2
 tarfile=$($SCRIPTS/get-tarfile-name $revision_build)
-RUN_OUTPUT=$(euca-run-instances -k id_rsa -t $INSTANCE_TYPE $AMI_IMAGE)
-if [ $? -ne 0 ]; then
-  exit 1
-fi
-
-instance_id=$(echo $RUN_OUTPUT|sed -r 's/.*INSTANCE (i-[^ ]*) .*/\1/')
+instance_id=$($SCRIPTS/ec2-run-instance-get-id)
 set +x
 echo Starting instance $instance_id
-instance_ip=''
-echo -n Waiting for IP address
-while [ -z "$instance_ip" ]; do
-  sleep 1
-  instance_ip=$(euca-describe-instances $instance_id|sed '/^INSTANCE/!d'|cut -f 17)
-  echo -n .
-done
-echo
-echo Instance has ip $instance_ip
+instance_name=$($SCRIPTS/ec2-get-name $instance_id)
+echo Instance has ip $instance_name
 sleep 30
-echo -n Waiting for SSH
-while ! netcat $instance_ip 22 -w 1 -q 0 </dev/null >/dev/null; do
-  sleep 1
-  echo -n .
-done
-echo
+$SCRIPTS/wait-for-port $instance_name 22
 set -x
 set +e
-ssh ubuntu@$instance_ip -o "StrictHostKeyChecking no" -o "UserKnownHostsFile /dev/null" <<EOT
+ssh ubuntu@$instance_name -o "StrictHostKeyChecking no" -o "UserKnownHostsFile /dev/null" <<EOT
 set -eux
 ssh-keygen -t rsa -b 2048 -N "" -f ~/.ssh/id_rsa
 wget -q $JENKINS_URL/job/build-revision/$revision_build/artifact/$tarfile

=== added file 'wait-for-port'
--- wait-for-port	1970-01-01 00:00:00 +0000
+++ wait-for-port	2014-02-21 15:35:49 +0000
@@ -0,0 +1,10 @@
+#!/bin/bash
+set -eu
+service=${2-SSH}
+port=${2-22}
+echo -n Waiting for $service >&2
+while ! netcat $1 $port -w 1 -q 0 </dev/null >/dev/null; do
+  sleep 1
+  echo -n . >&2
+done
+echo >&2

